% Matlab script file for batch processing of drug data. 

addpath('../PublicData/DukeWebSite/Pittman_zip');

txt2mat2('MatlabFiles/FiveFUTrainingGeneIDs.csv');
movefile('descriptions.mat','MatlabFiles/FiveFUTrainingdescriptions.mat');

UserOptions.excel = 'MatlabFiles/FiveFUTrainingQuant.csv';
UserOptions.descFile = 'MatlabFiles/FiveFUTrainingdescriptions.mat';
UserOptions.genes = 45;
UserOptions.metagenes = 5;
UserOptions.burnin = 500;
UserOptions.iteration = 1000;
UserOptions.skips = 2;
UserOptions.CI = 5;
UserOptions.crossvalidation = 1;
UserOptions.normalization = 1;

% produce figures and output files for later use

silent = 0;
run_binreg(UserOptions, silent);
figure(1);
set(gcf,'Color','w');
print('-dpng','MatlabFiles/Figures/FiveFUTrainingPCA.png');
print('-dpdf','MatlabFiles/Figures/FiveFUTrainingPCA.pdf');
print('-depsc','MatlabFiles/Figures/FiveFUTrainingPCA.eps');

figure(2);
set(gcf,'Color','w');
print('-dpng','MatlabFiles/Figures/FiveFUTrainingMetaWts.png');
print('-dpdf','MatlabFiles/Figures/FiveFUTrainingMetaWts.pdf');
print('-depsc','MatlabFiles/Figures/FiveFUTrainingMetaWts.eps');

figure(3);
set(gcf,'Color','w');
print('-dpng','MatlabFiles/Figures/FiveFUTrainingProbOutcome.png');
print('-dpdf','MatlabFiles/Figures/FiveFUTrainingProbOutcome.pdf');
print('-depsc','MatlabFiles/Figures/FiveFUTrainingProbOutcome.eps');

figure(5);
set(gcf,'Color','w');
print('-dpng','MatlabFiles/Figures/FiveFUTrainingCrossVal.png');
print('-dpdf','MatlabFiles/Figures/FiveFUTrainingCrossVal.pdf');
print('-depsc','MatlabFiles/Figures/FiveFUTrainingCrossVal.eps');

figure(11);
set(gcf,'Color','w');
title('5-FU, 45 Genes');
xlabel('Samples');
ylabel('Genes');
print('-dpng','MatlabFiles/Figures/FiveFUTrainingHeatmap.png');
print('-dpdf','MatlabFiles/Figures/FiveFUTrainingHeatmap.pdf');
print('-depsc','MatlabFiles/Figures/FiveFUTrainingHeatmap.eps');

movefile('imagegenelist.txt','MatlabFiles/FiveFUTrainingimagegenelist.txt');
movefile('topgenecoeffs.txt','MatlabFiles/FiveFUTrainingtopgenecoeffs.txt');
movefile('trainingcases.txt','MatlabFiles/FiveFUTrainingtrainingcases.txt');
movefile('normalisedX.txt','MatlabFiles/FiveFUTrainingnormalisedX.txt');

% produce a mat file (plotdata.mat) with the 
% numerical info needed to reproduce the figures. 

silent = 1;
run_binreg(UserOptions, silent);

load('plotdata.mat');
save('MatlabFiles/FiveFUTrainingplotdata.mat','Silent','-V6');

quit;
