% We want to assemble a panel of heatmaps similar
% to the one presented in figure 2 of Potti et al, 
% using the same ordering of genes:
% (1) Topotecan
% (2) Adriamycin
% (3) Etoposide
% (4) 5-FU
% (5) Paclitaxel
% (6) Cyclophosphamide

%addpath('../../PublicData/DukeWebSite/Pittman_zip');

flags.get_heatmap_data = 0;
flags.build_panel = 1;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get Heatmap Data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(flags.get_heatmap_data)
  
  load('TopoTrainingPlotData.mat');
  topo = Silent;
  X = topo.f11.XX;
  [m,k] = size(topo.f11.XX);
  [A,D,F] = svd_mw(X - repmat(mean(X,2),1,k));
  [b,i]=sort(A(:,1));
  i = flipud(i);
  XX = std_rows(X);
  imagesc(XX(i,:));
  topo.X_heatmap = XX(i,:);

  load('AdriaTrainingPlotData.mat');
  adria = Silent;
  X = adria.f11.XX;
  [m,k] = size(adria.f11.XX);
  [A,D,F] = svd_mw(X - repmat(mean(X,2),1,k));
  [b,i]=sort(A(:,1));
  i = flipud(i);
  XX = std_rows(X);
  imagesc(XX(i,:));
  adria.X_heatmap = XX(i,:);
  
  load('EtopoTrainingPlotData.mat');
  etopo = Silent;
  X = etopo.f11.XX;
  [m,k] = size(etopo.f11.XX);
  [A,D,F] = svd_mw(X - repmat(mean(X,2),1,k));
  [b,i]=sort(A(:,1));
  i = flipud(i);
  XX = std_rows(X);
  imagesc(XX(i,:));
  etopo.X_heatmap = XX(i,:);

  load('FiveFUTrainingPlotData.mat');
  fiveFU = Silent;
  X = fiveFU.f11.XX;
  [m,k] = size(fiveFU.f11.XX);
  [A,D,F] = svd_mw(X - repmat(mean(X,2),1,k));
  [b,i]=sort(A(:,1));
  i = flipud(i);
  XX = std_rows(X);
  imagesc(XX(i,:));
  fiveFU.X_heatmap = XX(i,:);

  load('TaxolTrainingPlotData.mat');
  taxol = Silent;
  X = taxol.f11.XX;
  [m,k] = size(taxol.f11.XX);
  [A,D,F] = svd_mw(X - repmat(mean(X,2),1,k));
  [b,i]=sort(A(:,1));
  i = flipud(i);
  XX = std_rows(X);
  imagesc(XX(i,:));
  taxol.X_heatmap = XX(i,:);

  load('CytoxTrainingPlotData.mat');
  cytox = Silent;
  X = cytox.f11.XX;
  [m,k] = size(cytox.f11.XX);
  [A,D,F] = svd_mw(X - repmat(mean(X,2),1,k));
  [b,i]=sort(A(:,1));
  i = flipud(i);
  XX = std_rows(X);
  imagesc(XX(i,:));
  cytox.X_heatmap = XX(i,:);

  clear X m k A D F b i XX;
  
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Get Heatmap Data
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(flags.build_panel)

  clf;
  
  set(gcf,'Position',[65 555 1000 180]);
  set(gcf,'Color','w');
  
  a1 = subplot(1,6,1);
  a2 = subplot(1,6,2);
  a3 = subplot(1,6,3);
  a4 = subplot(1,6,4);
  a5 = subplot(1,6,5);
  a6 = subplot(1,6,6);
  
  set(a1,'Position', [0.045, 0.10, 0.12, 0.825]);
  set(a2,'Position', [0.205, 0.10, 0.12, 0.825]);
  set(a3,'Position', [0.365, 0.10, 0.12, 0.825]);
  set(a4,'Position', [0.525, 0.10, 0.12, 0.825]);
  set(a5,'Position', [0.685, 0.10, 0.12, 0.825]);
  set(a6,'Position', [0.845, 0.10, 0.12, 0.825]);
  
  axes(a1);
  imagesc(topo.X_heatmap);
  title('Topotecan');
  axis square;
  
  axes(a2);
  imagesc(adria.X_heatmap);
  title('Adriamycin');
  axis square;
  
  axes(a3);
  imagesc(etopo.X_heatmap);
  title('Etoposide');
  axis square;
  
  axes(a4);
  imagesc(fiveFU.X_heatmap);
  title('5-FU');
  axis square;
  
  axes(a5);
  imagesc(taxol.X_heatmap);
  title('Paclitaxel');
  axis square;
  
  axes(a6);
  imagesc(cytox.X_heatmap);
  title('Cyclophosphamide');
  axis square;
  
  print('-dpng', 'software_heatmap_panel.png');
  print('-depsc', 'software_heatmap_panel.eps');
  print('-dpdf', 'software_heatmap_panel.pdf');
  
end

